import { getMenuByFullPath } from '../../store';
import { getRouterKey, getRouterTitle, isRedirectRouter } from '../../config/logic';
const __component__ = {
  name: 'Breadcrumb',
  data() {
    return {
      items: []
    };
  },
  computed: {
    linkableItems() {
      return this.items.slice(0, -1);
    },
    lastItem() {
      const {
        items
      } = this;
      return items.length === 0 ? undefined : items[items.length - 1];
    }
  },
  watch: {
    $route: {
      handler(to) {
        if (isRedirectRouter(to)) return;
        const result = this.generateBreadcrumb(to);
        if (result.length !== 0) {
          this.items = result;
        }
      },
      immediate: true
    }
  },
  methods: {
    onClick(fullPath) {
      let menu = getMenuByFullPath(fullPath);
      if (!menu) return;
      while (menu.children && menu.children.length >= 1) {
        menu = menu.children[0];
      }
      const {
        route
      } = this.$router.resolve(menu.fullPath);
      if (getRouterKey(route) !== getRouterKey(this.$route)) {
        this.$router.push(route);
      }
    },
    generateBreadcrumb(route) {
      const {
        path,
        fullPath,
        meta: {
          activeMenu
        }
      } = route;
      const menuFullPath = activeMenu || path;
      const menu = getMenuByFullPath(menuFullPath);
      if (!menu) return [];
      const items = [menu];
      let parent = menu.parent;
      while (parent) {
        items.unshift(parent);
        parent = parent.parent;
      }
      if (activeMenu) {
        items.push({
          fullPath,
          meta: {
            title: getRouterTitle(route)
          }
        });
      }
      return items;
    }
  }
};
var __render__ = function () {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c('div', {
    staticClass: "breadcrumb"
  }, [_c('transition-group', {
    attrs: {
      "name": "breadcrumb"
    }
  }, [_vm._l(_vm.linkableItems, function (ref) {
    var fullPath = ref.fullPath;
    var title = ref.meta.title;
    return _c('div', {
      key: fullPath,
      staticClass: "breadcrumb-item is-link"
    }, [_c('span', {
      staticClass: "breadcrumb-inner",
      on: {
        "click": function () {
          return _vm.onClick(fullPath);
        }
      }
    }, [_vm._v(_vm._s(title))]), _vm._v(" "), _c('span', {
      staticClass: "breadcrumb-separator"
    }, [_vm._v("/")])]);
  }), _vm._v(" "), _vm.lastItem ? _c('div', {
    key: _vm.lastItem.fullPath,
    staticClass: "breadcrumb-item"
  }, [_c('span', {
    staticClass: "breadcrumb-inner"
  }, [_vm._v(_vm._s(_vm.lastItem.meta.title))])]) : _vm._e()], 2)], 1);
};
var __staticRenderFns__ = [];
__component__.render = __render__;
__component__.staticRenderFns = __staticRenderFns__;
__component__._compiled = true;
export default __component__;