import { Const } from '../../config';
import Aside from '../Aside';
import Header from '../Header';
import TagsView from '../TagsView';
import Page from '../Page';
import { appGetters, appMutations, asideMutations, headerMutations, tagsViewGetters, tagsViewMutations, pageMutations } from '../../store';
import { isMobile } from '../../helper';
import { debounce } from '../../util';
export default {
  name: 'ElAdminLayout',
  computed: {
    renderAside() {
      const {
        isMobile,
        navMode
      } = appGetters;
      return isMobile || ['aside', 'mix'].includes(navMode);
    }
  },
  methods: {
    mutateStoreSlot() {
      const cache = this.cachedScopedSlots;
      const curr = this.$scopedSlots;
      Object.keys(cache).forEach(slotName => {
        if (!curr[slotName]) {
          const f = this.getMutationBySlot(slotName);
          f(undefined);
        }
      });
      Object.keys(curr).forEach(slotName => {
        if (!cache[slotName]) {
          const f = this.getMutationBySlot(slotName);
          if (!f) {
            console.error(`[el-admin-layout]: 插槽[${slotName}]不存在`);
            return;
          }
          f((h, props) => curr[slotName](props));
        }
      });
      this.cachedScopedSlots = curr;
    },
    getMutations(prefix) {
      switch (prefix) {
        case 'aside':
          return asideMutations;
        case 'header':
          return headerMutations;
        case 'page':
          return pageMutations;
      }
    },
    getMutationBySlot(slot) {
      const cache = this.slotMutationsMap;
      if (cache[slot]) return cache[slot];
      if (slot === 'logo') {
        cache[slot] = appMutations.logoSlot;
        return cache[slot];
      }
      if (slot === 'tags-view-item') {
        cache[slot] = tagsViewMutations.itemSlot;
        return cache[slot];
      }
      const arr = slot.split('-');
      const mutations = this.getMutations(arr[0]);
      if (arr.length === 1) {
        cache[slot] = mutations.defaultSlot;
        return cache[slot];
      }
      let method = arr[1];
      for (let i = 2, len = arr.length; i < len; i++) {
        const token = arr[i];
        method += token[0].toUpperCase() + [...token.slice(1)].join('');
      }
      return cache[slot] = mutations[method += 'Slot'];
    }
  },
  created() {
    this.$_resize = debounce(() => {
      !document.hidden && appMutations.isMobile(isMobile());
    });
    window.addEventListener('resize', this.$_resize);
    this.cachedScopedSlots = Object.create(null);
    this.slotMutationsMap = Object.create(null);
    this.$once('hook:beforeDestroy', () => {
      if (this.$_resize) {
        window.removeEventListener('resize', this.$_resize);
        delete this.$_resize;
      }
      delete this.cachedScopedSlots;
      delete this.slotMutationsMap;
    });
  },
  render() {
    const h = arguments[0];
    Const.enableLayoutSlot && this.mutateStoreSlot();
    const hasTagView = tagsViewGetters.enabled;
    const classList = ['el-admin-layout', 'has-header', hasTagView && 'has-tags-view', appGetters.struct];
    return h("div", {
      "class": classList
    }, [h(Header, {
      "ref": "header"
    }), hasTagView && h(TagsView, {
      "ref": "tags-view"
    }), this.renderAside && h(Aside, {
      "ref": "aside"
    }), h(Page, {
      "ref": "page"
    })]);
  }
};